.. _api:

API Reference
=============

.. module:: nereid 


Application Object
------------------

.. autoclass:: Nereid
   :members:


Templating
----------

.. autoclass:: nereid.templating.TrytonTemplateLoader
   :members:

.. autofunction:: nereid.templating.render_template


Backend - Tryton Connection
---------------------------

.. automodule:: nereid.backend
    :members:

Testing Helpers
---------------

.. automodule:: nereid.testing 
    :members:
